#[repr(u8)]pub enum Bootmode {
POWERUP = 0,
DEEPSLEEP = 1,
POWERDOWN = 2,
DEEPPOWERDOWN = 3,
}Variants
POWERUP = 0
Latest IC boot was a Full power cycle boot sequence (PoR, Pin Reset, Brown Out Detectors Reset, Software Reset).
DEEPSLEEP = 1
Latest IC boot was from DEEP SLEEP low power mode.
POWERDOWN = 2
Latest IC boot was from POWER DOWN low power mode.
DEEPPOWERDOWN = 3
Latest IC boot was from DEEP POWER DOWN low power mode.
Implementations